/*******************************************************************************
* File Name: LubricationTimer.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the LubricationTimer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "LubricationTimer.h"

uint8 LubricationTimer_initVar = 0u;


/*******************************************************************************
* Function Name: LubricationTimer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default LubricationTimer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (LubricationTimer__QUAD == LubricationTimer_CONFIG)
        LubricationTimer_CONTROL_REG = LubricationTimer_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        LubricationTimer_TRIG_CONTROL1_REG  = LubricationTimer_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        LubricationTimer_SetInterruptMode(LubricationTimer_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        LubricationTimer_SetCounterMode(LubricationTimer_COUNT_DOWN);
        LubricationTimer_WritePeriod(LubricationTimer_QUAD_PERIOD_INIT_VALUE);
        LubricationTimer_WriteCounter(LubricationTimer_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (LubricationTimer__QUAD == LubricationTimer_CONFIG) */

    #if (LubricationTimer__TIMER == LubricationTimer_CONFIG)
        LubricationTimer_CONTROL_REG = LubricationTimer_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        LubricationTimer_TRIG_CONTROL1_REG  = LubricationTimer_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        LubricationTimer_SetInterruptMode(LubricationTimer_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        LubricationTimer_WritePeriod(LubricationTimer_TC_PERIOD_VALUE );

        #if (LubricationTimer__COMPARE == LubricationTimer_TC_COMP_CAP_MODE)
            LubricationTimer_WriteCompare(LubricationTimer_TC_COMPARE_VALUE);

            #if (1u == LubricationTimer_TC_COMPARE_SWAP)
                LubricationTimer_SetCompareSwap(1u);
                LubricationTimer_WriteCompareBuf(LubricationTimer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == LubricationTimer_TC_COMPARE_SWAP) */
        #endif  /* (LubricationTimer__COMPARE == LubricationTimer_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (LubricationTimer_CY_TCPWM_V2 && LubricationTimer_TIMER_UPDOWN_CNT_USED && !LubricationTimer_CY_TCPWM_4000)
            LubricationTimer_WriteCounter(1u);
        #elif(LubricationTimer__COUNT_DOWN == LubricationTimer_TC_COUNTER_MODE)
            LubricationTimer_WriteCounter(LubricationTimer_TC_PERIOD_VALUE);
        #else
            LubricationTimer_WriteCounter(0u);
        #endif /* (LubricationTimer_CY_TCPWM_V2 && LubricationTimer_TIMER_UPDOWN_CNT_USED && !LubricationTimer_CY_TCPWM_4000) */
    #endif  /* (LubricationTimer__TIMER == LubricationTimer_CONFIG) */

    #if (LubricationTimer__PWM_SEL == LubricationTimer_CONFIG)
        LubricationTimer_CONTROL_REG = LubricationTimer_CTRL_PWM_BASE_CONFIG;

        #if (LubricationTimer__PWM_PR == LubricationTimer_PWM_MODE)
            LubricationTimer_CONTROL_REG |= LubricationTimer_CTRL_PWM_RUN_MODE;
            LubricationTimer_WriteCounter(LubricationTimer_PWM_PR_INIT_VALUE);
        #else
            LubricationTimer_CONTROL_REG |= LubricationTimer_CTRL_PWM_ALIGN | LubricationTimer_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (LubricationTimer_CY_TCPWM_V2 && LubricationTimer_PWM_UPDOWN_CNT_USED && !LubricationTimer_CY_TCPWM_4000)
                LubricationTimer_WriteCounter(1u);
            #elif (LubricationTimer__RIGHT == LubricationTimer_PWM_ALIGN)
                LubricationTimer_WriteCounter(LubricationTimer_PWM_PERIOD_VALUE);
            #else 
                LubricationTimer_WriteCounter(0u);
            #endif  /* (LubricationTimer_CY_TCPWM_V2 && LubricationTimer_PWM_UPDOWN_CNT_USED && !LubricationTimer_CY_TCPWM_4000) */
        #endif  /* (LubricationTimer__PWM_PR == LubricationTimer_PWM_MODE) */

        #if (LubricationTimer__PWM_DT == LubricationTimer_PWM_MODE)
            LubricationTimer_CONTROL_REG |= LubricationTimer_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (LubricationTimer__PWM_DT == LubricationTimer_PWM_MODE) */

        #if (LubricationTimer__PWM == LubricationTimer_PWM_MODE)
            LubricationTimer_CONTROL_REG |= LubricationTimer_CTRL_PWM_PRESCALER;
        #endif  /* (LubricationTimer__PWM == LubricationTimer_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        LubricationTimer_TRIG_CONTROL1_REG  = LubricationTimer_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        LubricationTimer_SetInterruptMode(LubricationTimer_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (LubricationTimer__PWM_PR == LubricationTimer_PWM_MODE)
            LubricationTimer_TRIG_CONTROL2_REG =
                    (LubricationTimer_CC_MATCH_NO_CHANGE    |
                    LubricationTimer_OVERLOW_NO_CHANGE      |
                    LubricationTimer_UNDERFLOW_NO_CHANGE);
        #else
            #if (LubricationTimer__LEFT == LubricationTimer_PWM_ALIGN)
                LubricationTimer_TRIG_CONTROL2_REG = LubricationTimer_PWM_MODE_LEFT;
            #endif  /* ( LubricationTimer_PWM_LEFT == LubricationTimer_PWM_ALIGN) */

            #if (LubricationTimer__RIGHT == LubricationTimer_PWM_ALIGN)
                LubricationTimer_TRIG_CONTROL2_REG = LubricationTimer_PWM_MODE_RIGHT;
            #endif  /* ( LubricationTimer_PWM_RIGHT == LubricationTimer_PWM_ALIGN) */

            #if (LubricationTimer__CENTER == LubricationTimer_PWM_ALIGN)
                LubricationTimer_TRIG_CONTROL2_REG = LubricationTimer_PWM_MODE_CENTER;
            #endif  /* ( LubricationTimer_PWM_CENTER == LubricationTimer_PWM_ALIGN) */

            #if (LubricationTimer__ASYMMETRIC == LubricationTimer_PWM_ALIGN)
                LubricationTimer_TRIG_CONTROL2_REG = LubricationTimer_PWM_MODE_ASYM;
            #endif  /* (LubricationTimer__ASYMMETRIC == LubricationTimer_PWM_ALIGN) */
        #endif  /* (LubricationTimer__PWM_PR == LubricationTimer_PWM_MODE) */

        /* Set other values from customizer */
        LubricationTimer_WritePeriod(LubricationTimer_PWM_PERIOD_VALUE );
        LubricationTimer_WriteCompare(LubricationTimer_PWM_COMPARE_VALUE);

        #if (1u == LubricationTimer_PWM_COMPARE_SWAP)
            LubricationTimer_SetCompareSwap(1u);
            LubricationTimer_WriteCompareBuf(LubricationTimer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == LubricationTimer_PWM_COMPARE_SWAP) */

        #if (1u == LubricationTimer_PWM_PERIOD_SWAP)
            LubricationTimer_SetPeriodSwap(1u);
            LubricationTimer_WritePeriodBuf(LubricationTimer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == LubricationTimer_PWM_PERIOD_SWAP) */
    #endif  /* (LubricationTimer__PWM_SEL == LubricationTimer_CONFIG) */
    
}


/*******************************************************************************
* Function Name: LubricationTimer_Enable
********************************************************************************
*
* Summary:
*  Enables the LubricationTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    LubricationTimer_BLOCK_CONTROL_REG |= LubricationTimer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (LubricationTimer__PWM_SEL == LubricationTimer_CONFIG)
        #if (0u == LubricationTimer_PWM_START_SIGNAL_PRESENT)
            LubricationTimer_TriggerCommand(LubricationTimer_MASK, LubricationTimer_CMD_START);
        #endif /* (0u == LubricationTimer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (LubricationTimer__PWM_SEL == LubricationTimer_CONFIG) */

    #if (LubricationTimer__TIMER == LubricationTimer_CONFIG)
        #if (0u == LubricationTimer_TC_START_SIGNAL_PRESENT)
            LubricationTimer_TriggerCommand(LubricationTimer_MASK, LubricationTimer_CMD_START);
        #endif /* (0u == LubricationTimer_TC_START_SIGNAL_PRESENT) */
    #endif /* (LubricationTimer__TIMER == LubricationTimer_CONFIG) */
}


/*******************************************************************************
* Function Name: LubricationTimer_Start
********************************************************************************
*
* Summary:
*  Initializes the LubricationTimer with default customizer
*  values when called the first time and enables the LubricationTimer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  LubricationTimer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time LubricationTimer_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the LubricationTimer_Start() routine.
*
*******************************************************************************/
void LubricationTimer_Start(void)
{
    if (0u == LubricationTimer_initVar)
    {
        LubricationTimer_Init();
        LubricationTimer_initVar = 1u;
    }

    LubricationTimer_Enable();
}


/*******************************************************************************
* Function Name: LubricationTimer_Stop
********************************************************************************
*
* Summary:
*  Disables the LubricationTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_BLOCK_CONTROL_REG &= (uint32)~LubricationTimer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the LubricationTimer. This function is used when
*  configured as a generic LubricationTimer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the LubricationTimer to operate in
*   Values:
*   - LubricationTimer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - LubricationTimer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - LubricationTimer_MODE_QUAD - Quadrature decoder
*         - LubricationTimer_MODE_PWM - PWM
*         - LubricationTimer_MODE_PWM_DT - PWM with dead time
*         - LubricationTimer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_MODE_MASK;
    LubricationTimer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - LubricationTimer_MODE_X1 - Counts on phi 1 rising
*         - LubricationTimer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - LubricationTimer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_QUAD_MODE_MASK;
    LubricationTimer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - LubricationTimer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - LubricationTimer_PRESCALE_DIVBY2    - Divide by 2
*         - LubricationTimer_PRESCALE_DIVBY4    - Divide by 4
*         - LubricationTimer_PRESCALE_DIVBY8    - Divide by 8
*         - LubricationTimer_PRESCALE_DIVBY16   - Divide by 16
*         - LubricationTimer_PRESCALE_DIVBY32   - Divide by 32
*         - LubricationTimer_PRESCALE_DIVBY64   - Divide by 64
*         - LubricationTimer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_PRESCALER_MASK;
    LubricationTimer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the LubricationTimer runs
*  continuously or stops when terminal count is reached.  By default the
*  LubricationTimer operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_ONESHOT_MASK;
    LubricationTimer_CONTROL_REG |= ((uint32)((oneShotEnable & LubricationTimer_1BIT_MASK) <<
                                                               LubricationTimer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPWMMode(uint32 modeMask)
{
    LubricationTimer_TRIG_CONTROL2_REG = (modeMask & LubricationTimer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: LubricationTimer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_PWM_SYNC_KILL_MASK;
    LubricationTimer_CONTROL_REG |= ((uint32)((syncKillEnable & LubricationTimer_1BIT_MASK)  <<
                                               LubricationTimer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_PWM_STOP_KILL_MASK;
    LubricationTimer_CONTROL_REG |= ((uint32)((stopOnKillEnable & LubricationTimer_1BIT_MASK)  <<
                                                         LubricationTimer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_PRESCALER_MASK;
    LubricationTimer_CONTROL_REG |= ((uint32)((deadTime & LubricationTimer_8BIT_MASK) <<
                                                          LubricationTimer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - LubricationTimer_INVERT_LINE   - Inverts the line output
*         - LubricationTimer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_INV_OUT_MASK;
    LubricationTimer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: LubricationTimer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_WriteCounter(uint32 count)
{
    LubricationTimer_COUNTER_REG = (count & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 LubricationTimer_ReadCounter(void)
{
    return (LubricationTimer_COUNTER_REG & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - LubricationTimer_COUNT_UP       - Counts up
*     - LubricationTimer_COUNT_DOWN     - Counts down
*     - LubricationTimer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - LubricationTimer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_UPDOWN_MASK;
    LubricationTimer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_WritePeriod(uint32 period)
{
    LubricationTimer_PERIOD_REG = (period & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 LubricationTimer_ReadPeriod(void)
{
    return (LubricationTimer_PERIOD_REG & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_RELOAD_CC_MASK;
    LubricationTimer_CONTROL_REG |= (swapEnable & LubricationTimer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_WritePeriodBuf(uint32 periodBuf)
{
    LubricationTimer_PERIOD_BUF_REG = (periodBuf & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 LubricationTimer_ReadPeriodBuf(void)
{
    return (LubricationTimer_PERIOD_BUF_REG & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_CONTROL_REG &= (uint32)~LubricationTimer_RELOAD_PERIOD_MASK;
    LubricationTimer_CONTROL_REG |= ((uint32)((swapEnable & LubricationTimer_1BIT_MASK) <<
                                                            LubricationTimer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_WriteCompare(uint32 compare)
{
    #if (LubricationTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (LubricationTimer_CY_TCPWM_4000) */

    #if (LubricationTimer_CY_TCPWM_4000)
        currentMode = ((LubricationTimer_CONTROL_REG & LubricationTimer_UPDOWN_MASK) >> LubricationTimer_UPDOWN_SHIFT);

        if (((uint32)LubricationTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)LubricationTimer__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (LubricationTimer_CY_TCPWM_4000) */
    
    LubricationTimer_COMP_CAP_REG = (compare & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 LubricationTimer_ReadCompare(void)
{
    #if (LubricationTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (LubricationTimer_CY_TCPWM_4000) */

    #if (LubricationTimer_CY_TCPWM_4000)
        currentMode = ((LubricationTimer_CONTROL_REG & LubricationTimer_UPDOWN_MASK) >> LubricationTimer_UPDOWN_SHIFT);
        
        regVal = LubricationTimer_COMP_CAP_REG;
        
        if (((uint32)LubricationTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)LubricationTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & LubricationTimer_16BIT_MASK);
    #else
        return (LubricationTimer_COMP_CAP_REG & LubricationTimer_16BIT_MASK);
    #endif /* (LubricationTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: LubricationTimer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_WriteCompareBuf(uint32 compareBuf)
{
    #if (LubricationTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (LubricationTimer_CY_TCPWM_4000) */

    #if (LubricationTimer_CY_TCPWM_4000)
        currentMode = ((LubricationTimer_CONTROL_REG & LubricationTimer_UPDOWN_MASK) >> LubricationTimer_UPDOWN_SHIFT);

        if (((uint32)LubricationTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)LubricationTimer__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (LubricationTimer_CY_TCPWM_4000) */
    
    LubricationTimer_COMP_CAP_BUF_REG = (compareBuf & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 LubricationTimer_ReadCompareBuf(void)
{
    #if (LubricationTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (LubricationTimer_CY_TCPWM_4000) */

    #if (LubricationTimer_CY_TCPWM_4000)
        currentMode = ((LubricationTimer_CONTROL_REG & LubricationTimer_UPDOWN_MASK) >> LubricationTimer_UPDOWN_SHIFT);

        regVal = LubricationTimer_COMP_CAP_BUF_REG;
        
        if (((uint32)LubricationTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)LubricationTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & LubricationTimer_16BIT_MASK);
    #else
        return (LubricationTimer_COMP_CAP_BUF_REG & LubricationTimer_16BIT_MASK);
    #endif /* (LubricationTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 LubricationTimer_ReadCapture(void)
{
    return (LubricationTimer_COMP_CAP_REG & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 LubricationTimer_ReadCaptureBuf(void)
{
    return (LubricationTimer_COMP_CAP_BUF_REG & LubricationTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LubricationTimer_TRIG_LEVEL     - Level
*     - LubricationTimer_TRIG_RISING    - Rising edge
*     - LubricationTimer_TRIG_FALLING   - Falling edge
*     - LubricationTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_TRIG_CONTROL1_REG &= (uint32)~LubricationTimer_CAPTURE_MASK;
    LubricationTimer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LubricationTimer_TRIG_LEVEL     - Level
*     - LubricationTimer_TRIG_RISING    - Rising edge
*     - LubricationTimer_TRIG_FALLING   - Falling edge
*     - LubricationTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_TRIG_CONTROL1_REG &= (uint32)~LubricationTimer_RELOAD_MASK;
    LubricationTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LubricationTimer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LubricationTimer_TRIG_LEVEL     - Level
*     - LubricationTimer_TRIG_RISING    - Rising edge
*     - LubricationTimer_TRIG_FALLING   - Falling edge
*     - LubricationTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_TRIG_CONTROL1_REG &= (uint32)~LubricationTimer_START_MASK;
    LubricationTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LubricationTimer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LubricationTimer_TRIG_LEVEL     - Level
*     - LubricationTimer_TRIG_RISING    - Rising edge
*     - LubricationTimer_TRIG_FALLING   - Falling edge
*     - LubricationTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_TRIG_CONTROL1_REG &= (uint32)~LubricationTimer_STOP_MASK;
    LubricationTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LubricationTimer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LubricationTimer_TRIG_LEVEL     - Level
*     - LubricationTimer_TRIG_RISING    - Rising edge
*     - LubricationTimer_TRIG_FALLING   - Falling edge
*     - LubricationTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_TRIG_CONTROL1_REG &= (uint32)~LubricationTimer_COUNT_MASK;
    LubricationTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LubricationTimer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - LubricationTimer_CMD_CAPTURE    - Trigger Capture command
*     - LubricationTimer_CMD_RELOAD     - Trigger Reload command
*     - LubricationTimer_CMD_STOP       - Trigger Stop command
*     - LubricationTimer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LubricationTimer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LubricationTimer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the LubricationTimer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - LubricationTimer_STATUS_DOWN    - Set if counting down
*     - LubricationTimer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 LubricationTimer_ReadStatus(void)
{
    return ((LubricationTimer_STATUS_REG >> LubricationTimer_RUNNING_STATUS_SHIFT) |
            (LubricationTimer_STATUS_REG & LubricationTimer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: LubricationTimer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - LubricationTimer_INTR_MASK_TC       - Terminal count mask
*     - LubricationTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetInterruptMode(uint32 interruptMask)
{
    LubricationTimer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: LubricationTimer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - LubricationTimer_INTR_MASK_TC       - Terminal count mask
*     - LubricationTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 LubricationTimer_GetInterruptSourceMasked(void)
{
    return (LubricationTimer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: LubricationTimer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - LubricationTimer_INTR_MASK_TC       - Terminal count mask
*     - LubricationTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 LubricationTimer_GetInterruptSource(void)
{
    return (LubricationTimer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: LubricationTimer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - LubricationTimer_INTR_MASK_TC       - Terminal count mask
*     - LubricationTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_ClearInterrupt(uint32 interruptMask)
{
    LubricationTimer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: LubricationTimer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - LubricationTimer_INTR_MASK_TC       - Terminal count mask
*     - LubricationTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SetInterrupt(uint32 interruptMask)
{
    LubricationTimer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
