/*******************************************************************************
* File Name: LubricationTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the LubricationTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_LubricationTimer_H)
#define CY_TCPWM_LubricationTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} LubricationTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  LubricationTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define LubricationTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define LubricationTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define LubricationTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define LubricationTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define LubricationTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define LubricationTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define LubricationTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define LubricationTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define LubricationTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define LubricationTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define LubricationTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define LubricationTimer_TC_RUN_MODE                    (0lu)
#define LubricationTimer_TC_COUNTER_MODE                (0lu)
#define LubricationTimer_TC_COMP_CAP_MODE               (2lu)
#define LubricationTimer_TC_PRESCALER                   (0lu)

/* Signal modes */
#define LubricationTimer_TC_RELOAD_SIGNAL_MODE          (1lu)
#define LubricationTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define LubricationTimer_TC_START_SIGNAL_MODE           (1lu)
#define LubricationTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define LubricationTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define LubricationTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define LubricationTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define LubricationTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define LubricationTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define LubricationTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define LubricationTimer_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define LubricationTimer_PWM_KILL_EVENT                 (0lu)
#define LubricationTimer_PWM_STOP_EVENT                 (0lu)
#define LubricationTimer_PWM_MODE                       (4lu)
#define LubricationTimer_PWM_OUT_N_INVERT               (0lu)
#define LubricationTimer_PWM_OUT_INVERT                 (0lu)
#define LubricationTimer_PWM_ALIGN                      (0lu)
#define LubricationTimer_PWM_RUN_MODE                   (0lu)
#define LubricationTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define LubricationTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define LubricationTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define LubricationTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define LubricationTimer_PWM_START_SIGNAL_MODE          (0lu)
#define LubricationTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define LubricationTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define LubricationTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define LubricationTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define LubricationTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define LubricationTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define LubricationTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define LubricationTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define LubricationTimer_TC_PERIOD_VALUE                (5000lu)
#define LubricationTimer_TC_COMPARE_VALUE               (65535lu)
#define LubricationTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define LubricationTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define LubricationTimer_PWM_PERIOD_VALUE               (65535lu)
#define LubricationTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define LubricationTimer_PWM_PERIOD_SWAP                (0lu)
#define LubricationTimer_PWM_COMPARE_VALUE              (65535lu)
#define LubricationTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define LubricationTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define LubricationTimer__LEFT 0
#define LubricationTimer__RIGHT 1
#define LubricationTimer__CENTER 2
#define LubricationTimer__ASYMMETRIC 3

#define LubricationTimer__X1 0
#define LubricationTimer__X2 1
#define LubricationTimer__X4 2

#define LubricationTimer__PWM 4
#define LubricationTimer__PWM_DT 5
#define LubricationTimer__PWM_PR 6

#define LubricationTimer__INVERSE 1
#define LubricationTimer__DIRECT 0

#define LubricationTimer__CAPTURE 2
#define LubricationTimer__COMPARE 0

#define LubricationTimer__TRIG_LEVEL 3
#define LubricationTimer__TRIG_RISING 0
#define LubricationTimer__TRIG_FALLING 1
#define LubricationTimer__TRIG_BOTH 2

#define LubricationTimer__INTR_MASK_TC 1
#define LubricationTimer__INTR_MASK_CC_MATCH 2
#define LubricationTimer__INTR_MASK_NONE 0
#define LubricationTimer__INTR_MASK_TC_CC 3

#define LubricationTimer__UNCONFIG 8
#define LubricationTimer__TIMER 1
#define LubricationTimer__QUAD 3
#define LubricationTimer__PWM_SEL 7

#define LubricationTimer__COUNT_UP 0
#define LubricationTimer__COUNT_DOWN 1
#define LubricationTimer__COUNT_UPDOWN0 2
#define LubricationTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define LubricationTimer_PRESCALE_DIVBY1                ((uint32)(0u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY2                ((uint32)(1u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY4                ((uint32)(2u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY8                ((uint32)(3u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY16               ((uint32)(4u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY32               ((uint32)(5u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY64               ((uint32)(6u << LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_PRESCALE_DIVBY128              ((uint32)(7u << LubricationTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define LubricationTimer_MODE_TIMER_COMPARE             ((uint32)(LubricationTimer__COMPARE         <<  \
                                                                  LubricationTimer_MODE_SHIFT))
#define LubricationTimer_MODE_TIMER_CAPTURE             ((uint32)(LubricationTimer__CAPTURE         <<  \
                                                                  LubricationTimer_MODE_SHIFT))
#define LubricationTimer_MODE_QUAD                      ((uint32)(LubricationTimer__QUAD            <<  \
                                                                  LubricationTimer_MODE_SHIFT))
#define LubricationTimer_MODE_PWM                       ((uint32)(LubricationTimer__PWM             <<  \
                                                                  LubricationTimer_MODE_SHIFT))
#define LubricationTimer_MODE_PWM_DT                    ((uint32)(LubricationTimer__PWM_DT          <<  \
                                                                  LubricationTimer_MODE_SHIFT))
#define LubricationTimer_MODE_PWM_PR                    ((uint32)(LubricationTimer__PWM_PR          <<  \
                                                                  LubricationTimer_MODE_SHIFT))

/* Quad Modes */
#define LubricationTimer_MODE_X1                        ((uint32)(LubricationTimer__X1              <<  \
                                                                  LubricationTimer_QUAD_MODE_SHIFT))
#define LubricationTimer_MODE_X2                        ((uint32)(LubricationTimer__X2              <<  \
                                                                  LubricationTimer_QUAD_MODE_SHIFT))
#define LubricationTimer_MODE_X4                        ((uint32)(LubricationTimer__X4              <<  \
                                                                  LubricationTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define LubricationTimer_COUNT_UP                       ((uint32)(LubricationTimer__COUNT_UP        <<  \
                                                                  LubricationTimer_UPDOWN_SHIFT))
#define LubricationTimer_COUNT_DOWN                     ((uint32)(LubricationTimer__COUNT_DOWN      <<  \
                                                                  LubricationTimer_UPDOWN_SHIFT))
#define LubricationTimer_COUNT_UPDOWN0                  ((uint32)(LubricationTimer__COUNT_UPDOWN0   <<  \
                                                                  LubricationTimer_UPDOWN_SHIFT))
#define LubricationTimer_COUNT_UPDOWN1                  ((uint32)(LubricationTimer__COUNT_UPDOWN1   <<  \
                                                                  LubricationTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define LubricationTimer_INVERT_LINE                    ((uint32)(LubricationTimer__INVERSE         <<  \
                                                                  LubricationTimer_INV_OUT_SHIFT))
#define LubricationTimer_INVERT_LINE_N                  ((uint32)(LubricationTimer__INVERSE         <<  \
                                                                  LubricationTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define LubricationTimer_TRIG_RISING                    ((uint32)LubricationTimer__TRIG_RISING)
#define LubricationTimer_TRIG_FALLING                   ((uint32)LubricationTimer__TRIG_FALLING)
#define LubricationTimer_TRIG_BOTH                      ((uint32)LubricationTimer__TRIG_BOTH)
#define LubricationTimer_TRIG_LEVEL                     ((uint32)LubricationTimer__TRIG_LEVEL)

/* Interrupt mask */
#define LubricationTimer_INTR_MASK_TC                   ((uint32)LubricationTimer__INTR_MASK_TC)
#define LubricationTimer_INTR_MASK_CC_MATCH             ((uint32)LubricationTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define LubricationTimer_CC_MATCH_SET                   (0x00u)
#define LubricationTimer_CC_MATCH_CLEAR                 (0x01u)
#define LubricationTimer_CC_MATCH_INVERT                (0x02u)
#define LubricationTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define LubricationTimer_OVERLOW_SET                    (0x00u)
#define LubricationTimer_OVERLOW_CLEAR                  (0x04u)
#define LubricationTimer_OVERLOW_INVERT                 (0x08u)
#define LubricationTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define LubricationTimer_UNDERFLOW_SET                  (0x00u)
#define LubricationTimer_UNDERFLOW_CLEAR                (0x10u)
#define LubricationTimer_UNDERFLOW_INVERT               (0x20u)
#define LubricationTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define LubricationTimer_PWM_MODE_LEFT                  (LubricationTimer_CC_MATCH_CLEAR        |   \
                                                         LubricationTimer_OVERLOW_SET           |   \
                                                         LubricationTimer_UNDERFLOW_NO_CHANGE)
#define LubricationTimer_PWM_MODE_RIGHT                 (LubricationTimer_CC_MATCH_SET          |   \
                                                         LubricationTimer_OVERLOW_NO_CHANGE     |   \
                                                         LubricationTimer_UNDERFLOW_CLEAR)
#define LubricationTimer_PWM_MODE_ASYM                  (LubricationTimer_CC_MATCH_INVERT       |   \
                                                         LubricationTimer_OVERLOW_SET           |   \
                                                         LubricationTimer_UNDERFLOW_CLEAR)

#if (LubricationTimer_CY_TCPWM_V2)
    #if(LubricationTimer_CY_TCPWM_4000)
        #define LubricationTimer_PWM_MODE_CENTER                (LubricationTimer_CC_MATCH_INVERT       |   \
                                                                 LubricationTimer_OVERLOW_NO_CHANGE     |   \
                                                                 LubricationTimer_UNDERFLOW_CLEAR)
    #else
        #define LubricationTimer_PWM_MODE_CENTER                (LubricationTimer_CC_MATCH_INVERT       |   \
                                                                 LubricationTimer_OVERLOW_SET           |   \
                                                                 LubricationTimer_UNDERFLOW_CLEAR)
    #endif /* (LubricationTimer_CY_TCPWM_4000) */
#else
    #define LubricationTimer_PWM_MODE_CENTER                (LubricationTimer_CC_MATCH_INVERT       |   \
                                                             LubricationTimer_OVERLOW_NO_CHANGE     |   \
                                                             LubricationTimer_UNDERFLOW_CLEAR)
#endif /* (LubricationTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define LubricationTimer_CMD_CAPTURE                    (0u)
#define LubricationTimer_CMD_RELOAD                     (8u)
#define LubricationTimer_CMD_STOP                       (16u)
#define LubricationTimer_CMD_START                      (24u)

/* Status */
#define LubricationTimer_STATUS_DOWN                    (1u)
#define LubricationTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   LubricationTimer_Init(void);
void   LubricationTimer_Enable(void);
void   LubricationTimer_Start(void);
void   LubricationTimer_Stop(void);

void   LubricationTimer_SetMode(uint32 mode);
void   LubricationTimer_SetCounterMode(uint32 counterMode);
void   LubricationTimer_SetPWMMode(uint32 modeMask);
void   LubricationTimer_SetQDMode(uint32 qdMode);

void   LubricationTimer_SetPrescaler(uint32 prescaler);
void   LubricationTimer_TriggerCommand(uint32 mask, uint32 command);
void   LubricationTimer_SetOneShot(uint32 oneShotEnable);
uint32 LubricationTimer_ReadStatus(void);

void   LubricationTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   LubricationTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   LubricationTimer_SetPWMDeadTime(uint32 deadTime);
void   LubricationTimer_SetPWMInvert(uint32 mask);

void   LubricationTimer_SetInterruptMode(uint32 interruptMask);
uint32 LubricationTimer_GetInterruptSourceMasked(void);
uint32 LubricationTimer_GetInterruptSource(void);
void   LubricationTimer_ClearInterrupt(uint32 interruptMask);
void   LubricationTimer_SetInterrupt(uint32 interruptMask);

void   LubricationTimer_WriteCounter(uint32 count);
uint32 LubricationTimer_ReadCounter(void);

uint32 LubricationTimer_ReadCapture(void);
uint32 LubricationTimer_ReadCaptureBuf(void);

void   LubricationTimer_WritePeriod(uint32 period);
uint32 LubricationTimer_ReadPeriod(void);
void   LubricationTimer_WritePeriodBuf(uint32 periodBuf);
uint32 LubricationTimer_ReadPeriodBuf(void);

void   LubricationTimer_WriteCompare(uint32 compare);
uint32 LubricationTimer_ReadCompare(void);
void   LubricationTimer_WriteCompareBuf(uint32 compareBuf);
uint32 LubricationTimer_ReadCompareBuf(void);

void   LubricationTimer_SetPeriodSwap(uint32 swapEnable);
void   LubricationTimer_SetCompareSwap(uint32 swapEnable);

void   LubricationTimer_SetCaptureMode(uint32 triggerMode);
void   LubricationTimer_SetReloadMode(uint32 triggerMode);
void   LubricationTimer_SetStartMode(uint32 triggerMode);
void   LubricationTimer_SetStopMode(uint32 triggerMode);
void   LubricationTimer_SetCountMode(uint32 triggerMode);

void   LubricationTimer_SaveConfig(void);
void   LubricationTimer_RestoreConfig(void);
void   LubricationTimer_Sleep(void);
void   LubricationTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define LubricationTimer_BLOCK_CONTROL_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define LubricationTimer_BLOCK_CONTROL_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define LubricationTimer_COMMAND_REG                    (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define LubricationTimer_COMMAND_PTR                    ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define LubricationTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define LubricationTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define LubricationTimer_CONTROL_REG                    (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CTRL )
#define LubricationTimer_CONTROL_PTR                    ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CTRL )
#define LubricationTimer_STATUS_REG                     (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__STATUS )
#define LubricationTimer_STATUS_PTR                     ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__STATUS )
#define LubricationTimer_COUNTER_REG                    (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__COUNTER )
#define LubricationTimer_COUNTER_PTR                    ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__COUNTER )
#define LubricationTimer_COMP_CAP_REG                   (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CC )
#define LubricationTimer_COMP_CAP_PTR                   ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CC )
#define LubricationTimer_COMP_CAP_BUF_REG               (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define LubricationTimer_COMP_CAP_BUF_PTR               ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define LubricationTimer_PERIOD_REG                     (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__PERIOD )
#define LubricationTimer_PERIOD_PTR                     ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__PERIOD )
#define LubricationTimer_PERIOD_BUF_REG                 (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define LubricationTimer_PERIOD_BUF_PTR                 ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define LubricationTimer_TRIG_CONTROL0_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define LubricationTimer_TRIG_CONTROL0_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define LubricationTimer_TRIG_CONTROL1_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define LubricationTimer_TRIG_CONTROL1_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define LubricationTimer_TRIG_CONTROL2_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define LubricationTimer_TRIG_CONTROL2_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define LubricationTimer_INTERRUPT_REQ_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR )
#define LubricationTimer_INTERRUPT_REQ_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR )
#define LubricationTimer_INTERRUPT_SET_REG              (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define LubricationTimer_INTERRUPT_SET_PTR              ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define LubricationTimer_INTERRUPT_MASK_REG             (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define LubricationTimer_INTERRUPT_MASK_PTR             ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define LubricationTimer_INTERRUPT_MASKED_REG           (*(reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define LubricationTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) LubricationTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define LubricationTimer_MASK                           ((uint32)LubricationTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define LubricationTimer_RELOAD_CC_SHIFT                (0u)
#define LubricationTimer_RELOAD_PERIOD_SHIFT            (1u)
#define LubricationTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define LubricationTimer_PWM_STOP_KILL_SHIFT            (3u)
#define LubricationTimer_PRESCALER_SHIFT                (8u)
#define LubricationTimer_UPDOWN_SHIFT                   (16u)
#define LubricationTimer_ONESHOT_SHIFT                  (18u)
#define LubricationTimer_QUAD_MODE_SHIFT                (20u)
#define LubricationTimer_INV_OUT_SHIFT                  (20u)
#define LubricationTimer_INV_COMPL_OUT_SHIFT            (21u)
#define LubricationTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define LubricationTimer_RELOAD_CC_MASK                 ((uint32)(LubricationTimer_1BIT_MASK        <<  \
                                                                            LubricationTimer_RELOAD_CC_SHIFT))
#define LubricationTimer_RELOAD_PERIOD_MASK             ((uint32)(LubricationTimer_1BIT_MASK        <<  \
                                                                            LubricationTimer_RELOAD_PERIOD_SHIFT))
#define LubricationTimer_PWM_SYNC_KILL_MASK             ((uint32)(LubricationTimer_1BIT_MASK        <<  \
                                                                            LubricationTimer_PWM_SYNC_KILL_SHIFT))
#define LubricationTimer_PWM_STOP_KILL_MASK             ((uint32)(LubricationTimer_1BIT_MASK        <<  \
                                                                            LubricationTimer_PWM_STOP_KILL_SHIFT))
#define LubricationTimer_PRESCALER_MASK                 ((uint32)(LubricationTimer_8BIT_MASK        <<  \
                                                                            LubricationTimer_PRESCALER_SHIFT))
#define LubricationTimer_UPDOWN_MASK                    ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                            LubricationTimer_UPDOWN_SHIFT))
#define LubricationTimer_ONESHOT_MASK                   ((uint32)(LubricationTimer_1BIT_MASK        <<  \
                                                                            LubricationTimer_ONESHOT_SHIFT))
#define LubricationTimer_QUAD_MODE_MASK                 ((uint32)(LubricationTimer_3BIT_MASK        <<  \
                                                                            LubricationTimer_QUAD_MODE_SHIFT))
#define LubricationTimer_INV_OUT_MASK                   ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                            LubricationTimer_INV_OUT_SHIFT))
#define LubricationTimer_MODE_MASK                      ((uint32)(LubricationTimer_3BIT_MASK        <<  \
                                                                            LubricationTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define LubricationTimer_CAPTURE_SHIFT                  (0u)
#define LubricationTimer_COUNT_SHIFT                    (2u)
#define LubricationTimer_RELOAD_SHIFT                   (4u)
#define LubricationTimer_STOP_SHIFT                     (6u)
#define LubricationTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define LubricationTimer_CAPTURE_MASK                   ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                  LubricationTimer_CAPTURE_SHIFT))
#define LubricationTimer_COUNT_MASK                     ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                  LubricationTimer_COUNT_SHIFT))
#define LubricationTimer_RELOAD_MASK                    ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                  LubricationTimer_RELOAD_SHIFT))
#define LubricationTimer_STOP_MASK                      ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                  LubricationTimer_STOP_SHIFT))
#define LubricationTimer_START_MASK                     ((uint32)(LubricationTimer_2BIT_MASK        <<  \
                                                                  LubricationTimer_START_SHIFT))

/* MASK */
#define LubricationTimer_1BIT_MASK                      ((uint32)0x01u)
#define LubricationTimer_2BIT_MASK                      ((uint32)0x03u)
#define LubricationTimer_3BIT_MASK                      ((uint32)0x07u)
#define LubricationTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define LubricationTimer_8BIT_MASK                      ((uint32)0xFFu)
#define LubricationTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define LubricationTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define LubricationTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(LubricationTimer_QUAD_ENCODING_MODES     << LubricationTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(LubricationTimer_CONFIG                  << LubricationTimer_MODE_SHIFT)))

#define LubricationTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(LubricationTimer_PWM_STOP_EVENT          << LubricationTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(LubricationTimer_PWM_OUT_INVERT          << LubricationTimer_INV_OUT_SHIFT))         |\
         ((uint32)(LubricationTimer_PWM_OUT_N_INVERT        << LubricationTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(LubricationTimer_PWM_MODE                << LubricationTimer_MODE_SHIFT)))

#define LubricationTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(LubricationTimer_PWM_RUN_MODE         << LubricationTimer_ONESHOT_SHIFT))
            
#define LubricationTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(LubricationTimer_PWM_ALIGN            << LubricationTimer_UPDOWN_SHIFT))

#define LubricationTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(LubricationTimer_PWM_KILL_EVENT      << LubricationTimer_PWM_SYNC_KILL_SHIFT))

#define LubricationTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(LubricationTimer_PWM_DEAD_TIME_CYCLE  << LubricationTimer_PRESCALER_SHIFT))

#define LubricationTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(LubricationTimer_PWM_PRESCALER        << LubricationTimer_PRESCALER_SHIFT))

#define LubricationTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(LubricationTimer_TC_PRESCALER            << LubricationTimer_PRESCALER_SHIFT))       |\
         ((uint32)(LubricationTimer_TC_COUNTER_MODE         << LubricationTimer_UPDOWN_SHIFT))          |\
         ((uint32)(LubricationTimer_TC_RUN_MODE             << LubricationTimer_ONESHOT_SHIFT))         |\
         ((uint32)(LubricationTimer_TC_COMP_CAP_MODE        << LubricationTimer_MODE_SHIFT)))
        
#define LubricationTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(LubricationTimer_QUAD_PHIA_SIGNAL_MODE   << LubricationTimer_COUNT_SHIFT))           |\
         ((uint32)(LubricationTimer_QUAD_INDEX_SIGNAL_MODE  << LubricationTimer_RELOAD_SHIFT))          |\
         ((uint32)(LubricationTimer_QUAD_STOP_SIGNAL_MODE   << LubricationTimer_STOP_SHIFT))            |\
         ((uint32)(LubricationTimer_QUAD_PHIB_SIGNAL_MODE   << LubricationTimer_START_SHIFT)))

#define LubricationTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(LubricationTimer_PWM_SWITCH_SIGNAL_MODE  << LubricationTimer_CAPTURE_SHIFT))         |\
         ((uint32)(LubricationTimer_PWM_COUNT_SIGNAL_MODE   << LubricationTimer_COUNT_SHIFT))           |\
         ((uint32)(LubricationTimer_PWM_RELOAD_SIGNAL_MODE  << LubricationTimer_RELOAD_SHIFT))          |\
         ((uint32)(LubricationTimer_PWM_STOP_SIGNAL_MODE    << LubricationTimer_STOP_SHIFT))            |\
         ((uint32)(LubricationTimer_PWM_START_SIGNAL_MODE   << LubricationTimer_START_SHIFT)))

#define LubricationTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(LubricationTimer_TC_CAPTURE_SIGNAL_MODE  << LubricationTimer_CAPTURE_SHIFT))         |\
         ((uint32)(LubricationTimer_TC_COUNT_SIGNAL_MODE    << LubricationTimer_COUNT_SHIFT))           |\
         ((uint32)(LubricationTimer_TC_RELOAD_SIGNAL_MODE   << LubricationTimer_RELOAD_SHIFT))          |\
         ((uint32)(LubricationTimer_TC_STOP_SIGNAL_MODE     << LubricationTimer_STOP_SHIFT))            |\
         ((uint32)(LubricationTimer_TC_START_SIGNAL_MODE    << LubricationTimer_START_SHIFT)))
        
#define LubricationTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((LubricationTimer__COUNT_UPDOWN0 == LubricationTimer_TC_COUNTER_MODE)                  ||\
                 (LubricationTimer__COUNT_UPDOWN1 == LubricationTimer_TC_COUNTER_MODE))

#define LubricationTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((LubricationTimer__CENTER == LubricationTimer_PWM_ALIGN)                               ||\
                 (LubricationTimer__ASYMMETRIC == LubricationTimer_PWM_ALIGN))               
        
#define LubricationTimer_PWM_PR_INIT_VALUE              (1u)
#define LubricationTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_LubricationTimer_H */

/* [] END OF FILE */
