/*******************************************************************************
* File Name: LubricationTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "LubricationTimer.h"

static LubricationTimer_BACKUP_STRUCT LubricationTimer_backup;


/*******************************************************************************
* Function Name: LubricationTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: LubricationTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_Sleep(void)
{
    if(0u != (LubricationTimer_BLOCK_CONTROL_REG & LubricationTimer_MASK))
    {
        LubricationTimer_backup.enableState = 1u;
    }
    else
    {
        LubricationTimer_backup.enableState = 0u;
    }

    LubricationTimer_Stop();
    LubricationTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: LubricationTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: LubricationTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LubricationTimer_Wakeup(void)
{
    LubricationTimer_RestoreConfig();

    if(0u != LubricationTimer_backup.enableState)
    {
        LubricationTimer_Enable();
    }
}


/* [] END OF FILE */
