/*******************************************************************************
* File Name: SleepTimer.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the SleepTimer
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_SleepTimer_H)
#define CY_TCPWM_SleepTimer_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} SleepTimer_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  SleepTimer_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define SleepTimer_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define SleepTimer_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define SleepTimer_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define SleepTimer_QUAD_ENCODING_MODES            (0lu)

/* Signal modes */
#define SleepTimer_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define SleepTimer_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define SleepTimer_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define SleepTimer_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define SleepTimer_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define SleepTimer_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define SleepTimer_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define SleepTimer_TC_RUN_MODE                    (0lu)
#define SleepTimer_TC_COUNTER_MODE                (0lu)
#define SleepTimer_TC_COMP_CAP_MODE               (2lu)
#define SleepTimer_TC_PRESCALER                   (0lu)

/* Signal modes */
#define SleepTimer_TC_RELOAD_SIGNAL_MODE          (1lu)
#define SleepTimer_TC_COUNT_SIGNAL_MODE           (3lu)
#define SleepTimer_TC_START_SIGNAL_MODE           (1lu)
#define SleepTimer_TC_STOP_SIGNAL_MODE            (0lu)
#define SleepTimer_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define SleepTimer_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define SleepTimer_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define SleepTimer_TC_START_SIGNAL_PRESENT        (0lu)
#define SleepTimer_TC_STOP_SIGNAL_PRESENT         (0lu)
#define SleepTimer_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define SleepTimer_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define SleepTimer_PWM_KILL_EVENT                 (0lu)
#define SleepTimer_PWM_STOP_EVENT                 (0lu)
#define SleepTimer_PWM_MODE                       (4lu)
#define SleepTimer_PWM_OUT_N_INVERT               (0lu)
#define SleepTimer_PWM_OUT_INVERT                 (0lu)
#define SleepTimer_PWM_ALIGN                      (0lu)
#define SleepTimer_PWM_RUN_MODE                   (0lu)
#define SleepTimer_PWM_DEAD_TIME_CYCLE            (0lu)
#define SleepTimer_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define SleepTimer_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define SleepTimer_PWM_COUNT_SIGNAL_MODE          (3lu)
#define SleepTimer_PWM_START_SIGNAL_MODE          (0lu)
#define SleepTimer_PWM_STOP_SIGNAL_MODE           (0lu)
#define SleepTimer_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define SleepTimer_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define SleepTimer_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define SleepTimer_PWM_START_SIGNAL_PRESENT       (0lu)
#define SleepTimer_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define SleepTimer_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define SleepTimer_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define SleepTimer_TC_PERIOD_VALUE                (5000lu)
#define SleepTimer_TC_COMPARE_VALUE               (65535lu)
#define SleepTimer_TC_COMPARE_BUF_VALUE           (65535lu)
#define SleepTimer_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define SleepTimer_PWM_PERIOD_VALUE               (65535lu)
#define SleepTimer_PWM_PERIOD_BUF_VALUE           (65535lu)
#define SleepTimer_PWM_PERIOD_SWAP                (0lu)
#define SleepTimer_PWM_COMPARE_VALUE              (65535lu)
#define SleepTimer_PWM_COMPARE_BUF_VALUE          (65535lu)
#define SleepTimer_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define SleepTimer__LEFT 0
#define SleepTimer__RIGHT 1
#define SleepTimer__CENTER 2
#define SleepTimer__ASYMMETRIC 3

#define SleepTimer__X1 0
#define SleepTimer__X2 1
#define SleepTimer__X4 2

#define SleepTimer__PWM 4
#define SleepTimer__PWM_DT 5
#define SleepTimer__PWM_PR 6

#define SleepTimer__INVERSE 1
#define SleepTimer__DIRECT 0

#define SleepTimer__CAPTURE 2
#define SleepTimer__COMPARE 0

#define SleepTimer__TRIG_LEVEL 3
#define SleepTimer__TRIG_RISING 0
#define SleepTimer__TRIG_FALLING 1
#define SleepTimer__TRIG_BOTH 2

#define SleepTimer__INTR_MASK_TC 1
#define SleepTimer__INTR_MASK_CC_MATCH 2
#define SleepTimer__INTR_MASK_NONE 0
#define SleepTimer__INTR_MASK_TC_CC 3

#define SleepTimer__UNCONFIG 8
#define SleepTimer__TIMER 1
#define SleepTimer__QUAD 3
#define SleepTimer__PWM_SEL 7

#define SleepTimer__COUNT_UP 0
#define SleepTimer__COUNT_DOWN 1
#define SleepTimer__COUNT_UPDOWN0 2
#define SleepTimer__COUNT_UPDOWN1 3


/* Prescaler */
#define SleepTimer_PRESCALE_DIVBY1                ((uint32)(0u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY2                ((uint32)(1u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY4                ((uint32)(2u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY8                ((uint32)(3u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY16               ((uint32)(4u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY32               ((uint32)(5u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY64               ((uint32)(6u << SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_PRESCALE_DIVBY128              ((uint32)(7u << SleepTimer_PRESCALER_SHIFT))

/* TCPWM set modes */
#define SleepTimer_MODE_TIMER_COMPARE             ((uint32)(SleepTimer__COMPARE         <<  \
                                                                  SleepTimer_MODE_SHIFT))
#define SleepTimer_MODE_TIMER_CAPTURE             ((uint32)(SleepTimer__CAPTURE         <<  \
                                                                  SleepTimer_MODE_SHIFT))
#define SleepTimer_MODE_QUAD                      ((uint32)(SleepTimer__QUAD            <<  \
                                                                  SleepTimer_MODE_SHIFT))
#define SleepTimer_MODE_PWM                       ((uint32)(SleepTimer__PWM             <<  \
                                                                  SleepTimer_MODE_SHIFT))
#define SleepTimer_MODE_PWM_DT                    ((uint32)(SleepTimer__PWM_DT          <<  \
                                                                  SleepTimer_MODE_SHIFT))
#define SleepTimer_MODE_PWM_PR                    ((uint32)(SleepTimer__PWM_PR          <<  \
                                                                  SleepTimer_MODE_SHIFT))

/* Quad Modes */
#define SleepTimer_MODE_X1                        ((uint32)(SleepTimer__X1              <<  \
                                                                  SleepTimer_QUAD_MODE_SHIFT))
#define SleepTimer_MODE_X2                        ((uint32)(SleepTimer__X2              <<  \
                                                                  SleepTimer_QUAD_MODE_SHIFT))
#define SleepTimer_MODE_X4                        ((uint32)(SleepTimer__X4              <<  \
                                                                  SleepTimer_QUAD_MODE_SHIFT))

/* Counter modes */
#define SleepTimer_COUNT_UP                       ((uint32)(SleepTimer__COUNT_UP        <<  \
                                                                  SleepTimer_UPDOWN_SHIFT))
#define SleepTimer_COUNT_DOWN                     ((uint32)(SleepTimer__COUNT_DOWN      <<  \
                                                                  SleepTimer_UPDOWN_SHIFT))
#define SleepTimer_COUNT_UPDOWN0                  ((uint32)(SleepTimer__COUNT_UPDOWN0   <<  \
                                                                  SleepTimer_UPDOWN_SHIFT))
#define SleepTimer_COUNT_UPDOWN1                  ((uint32)(SleepTimer__COUNT_UPDOWN1   <<  \
                                                                  SleepTimer_UPDOWN_SHIFT))

/* PWM output invert */
#define SleepTimer_INVERT_LINE                    ((uint32)(SleepTimer__INVERSE         <<  \
                                                                  SleepTimer_INV_OUT_SHIFT))
#define SleepTimer_INVERT_LINE_N                  ((uint32)(SleepTimer__INVERSE         <<  \
                                                                  SleepTimer_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define SleepTimer_TRIG_RISING                    ((uint32)SleepTimer__TRIG_RISING)
#define SleepTimer_TRIG_FALLING                   ((uint32)SleepTimer__TRIG_FALLING)
#define SleepTimer_TRIG_BOTH                      ((uint32)SleepTimer__TRIG_BOTH)
#define SleepTimer_TRIG_LEVEL                     ((uint32)SleepTimer__TRIG_LEVEL)

/* Interrupt mask */
#define SleepTimer_INTR_MASK_TC                   ((uint32)SleepTimer__INTR_MASK_TC)
#define SleepTimer_INTR_MASK_CC_MATCH             ((uint32)SleepTimer__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define SleepTimer_CC_MATCH_SET                   (0x00u)
#define SleepTimer_CC_MATCH_CLEAR                 (0x01u)
#define SleepTimer_CC_MATCH_INVERT                (0x02u)
#define SleepTimer_CC_MATCH_NO_CHANGE             (0x03u)
#define SleepTimer_OVERLOW_SET                    (0x00u)
#define SleepTimer_OVERLOW_CLEAR                  (0x04u)
#define SleepTimer_OVERLOW_INVERT                 (0x08u)
#define SleepTimer_OVERLOW_NO_CHANGE              (0x0Cu)
#define SleepTimer_UNDERFLOW_SET                  (0x00u)
#define SleepTimer_UNDERFLOW_CLEAR                (0x10u)
#define SleepTimer_UNDERFLOW_INVERT               (0x20u)
#define SleepTimer_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define SleepTimer_PWM_MODE_LEFT                  (SleepTimer_CC_MATCH_CLEAR        |   \
                                                         SleepTimer_OVERLOW_SET           |   \
                                                         SleepTimer_UNDERFLOW_NO_CHANGE)
#define SleepTimer_PWM_MODE_RIGHT                 (SleepTimer_CC_MATCH_SET          |   \
                                                         SleepTimer_OVERLOW_NO_CHANGE     |   \
                                                         SleepTimer_UNDERFLOW_CLEAR)
#define SleepTimer_PWM_MODE_ASYM                  (SleepTimer_CC_MATCH_INVERT       |   \
                                                         SleepTimer_OVERLOW_SET           |   \
                                                         SleepTimer_UNDERFLOW_CLEAR)

#if (SleepTimer_CY_TCPWM_V2)
    #if(SleepTimer_CY_TCPWM_4000)
        #define SleepTimer_PWM_MODE_CENTER                (SleepTimer_CC_MATCH_INVERT       |   \
                                                                 SleepTimer_OVERLOW_NO_CHANGE     |   \
                                                                 SleepTimer_UNDERFLOW_CLEAR)
    #else
        #define SleepTimer_PWM_MODE_CENTER                (SleepTimer_CC_MATCH_INVERT       |   \
                                                                 SleepTimer_OVERLOW_SET           |   \
                                                                 SleepTimer_UNDERFLOW_CLEAR)
    #endif /* (SleepTimer_CY_TCPWM_4000) */
#else
    #define SleepTimer_PWM_MODE_CENTER                (SleepTimer_CC_MATCH_INVERT       |   \
                                                             SleepTimer_OVERLOW_NO_CHANGE     |   \
                                                             SleepTimer_UNDERFLOW_CLEAR)
#endif /* (SleepTimer_CY_TCPWM_NEW) */

/* Command operations without condition */
#define SleepTimer_CMD_CAPTURE                    (0u)
#define SleepTimer_CMD_RELOAD                     (8u)
#define SleepTimer_CMD_STOP                       (16u)
#define SleepTimer_CMD_START                      (24u)

/* Status */
#define SleepTimer_STATUS_DOWN                    (1u)
#define SleepTimer_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   SleepTimer_Init(void);
void   SleepTimer_Enable(void);
void   SleepTimer_Start(void);
void   SleepTimer_Stop(void);

void   SleepTimer_SetMode(uint32 mode);
void   SleepTimer_SetCounterMode(uint32 counterMode);
void   SleepTimer_SetPWMMode(uint32 modeMask);
void   SleepTimer_SetQDMode(uint32 qdMode);

void   SleepTimer_SetPrescaler(uint32 prescaler);
void   SleepTimer_TriggerCommand(uint32 mask, uint32 command);
void   SleepTimer_SetOneShot(uint32 oneShotEnable);
uint32 SleepTimer_ReadStatus(void);

void   SleepTimer_SetPWMSyncKill(uint32 syncKillEnable);
void   SleepTimer_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   SleepTimer_SetPWMDeadTime(uint32 deadTime);
void   SleepTimer_SetPWMInvert(uint32 mask);

void   SleepTimer_SetInterruptMode(uint32 interruptMask);
uint32 SleepTimer_GetInterruptSourceMasked(void);
uint32 SleepTimer_GetInterruptSource(void);
void   SleepTimer_ClearInterrupt(uint32 interruptMask);
void   SleepTimer_SetInterrupt(uint32 interruptMask);

void   SleepTimer_WriteCounter(uint32 count);
uint32 SleepTimer_ReadCounter(void);

uint32 SleepTimer_ReadCapture(void);
uint32 SleepTimer_ReadCaptureBuf(void);

void   SleepTimer_WritePeriod(uint32 period);
uint32 SleepTimer_ReadPeriod(void);
void   SleepTimer_WritePeriodBuf(uint32 periodBuf);
uint32 SleepTimer_ReadPeriodBuf(void);

void   SleepTimer_WriteCompare(uint32 compare);
uint32 SleepTimer_ReadCompare(void);
void   SleepTimer_WriteCompareBuf(uint32 compareBuf);
uint32 SleepTimer_ReadCompareBuf(void);

void   SleepTimer_SetPeriodSwap(uint32 swapEnable);
void   SleepTimer_SetCompareSwap(uint32 swapEnable);

void   SleepTimer_SetCaptureMode(uint32 triggerMode);
void   SleepTimer_SetReloadMode(uint32 triggerMode);
void   SleepTimer_SetStartMode(uint32 triggerMode);
void   SleepTimer_SetStopMode(uint32 triggerMode);
void   SleepTimer_SetCountMode(uint32 triggerMode);

void   SleepTimer_SaveConfig(void);
void   SleepTimer_RestoreConfig(void);
void   SleepTimer_Sleep(void);
void   SleepTimer_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define SleepTimer_BLOCK_CONTROL_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define SleepTimer_BLOCK_CONTROL_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define SleepTimer_COMMAND_REG                    (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define SleepTimer_COMMAND_PTR                    ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define SleepTimer_INTRRUPT_CAUSE_REG             (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define SleepTimer_INTRRUPT_CAUSE_PTR             ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define SleepTimer_CONTROL_REG                    (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CTRL )
#define SleepTimer_CONTROL_PTR                    ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CTRL )
#define SleepTimer_STATUS_REG                     (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__STATUS )
#define SleepTimer_STATUS_PTR                     ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__STATUS )
#define SleepTimer_COUNTER_REG                    (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__COUNTER )
#define SleepTimer_COUNTER_PTR                    ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__COUNTER )
#define SleepTimer_COMP_CAP_REG                   (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CC )
#define SleepTimer_COMP_CAP_PTR                   ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CC )
#define SleepTimer_COMP_CAP_BUF_REG               (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define SleepTimer_COMP_CAP_BUF_PTR               ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__CC_BUFF )
#define SleepTimer_PERIOD_REG                     (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__PERIOD )
#define SleepTimer_PERIOD_PTR                     ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__PERIOD )
#define SleepTimer_PERIOD_BUF_REG                 (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define SleepTimer_PERIOD_BUF_PTR                 ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define SleepTimer_TRIG_CONTROL0_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define SleepTimer_TRIG_CONTROL0_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define SleepTimer_TRIG_CONTROL1_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define SleepTimer_TRIG_CONTROL1_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define SleepTimer_TRIG_CONTROL2_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define SleepTimer_TRIG_CONTROL2_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define SleepTimer_INTERRUPT_REQ_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR )
#define SleepTimer_INTERRUPT_REQ_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR )
#define SleepTimer_INTERRUPT_SET_REG              (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define SleepTimer_INTERRUPT_SET_PTR              ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_SET )
#define SleepTimer_INTERRUPT_MASK_REG             (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define SleepTimer_INTERRUPT_MASK_PTR             ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_MASK )
#define SleepTimer_INTERRUPT_MASKED_REG           (*(reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_MASKED )
#define SleepTimer_INTERRUPT_MASKED_PTR           ( (reg32 *) SleepTimer_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define SleepTimer_MASK                           ((uint32)SleepTimer_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define SleepTimer_RELOAD_CC_SHIFT                (0u)
#define SleepTimer_RELOAD_PERIOD_SHIFT            (1u)
#define SleepTimer_PWM_SYNC_KILL_SHIFT            (2u)
#define SleepTimer_PWM_STOP_KILL_SHIFT            (3u)
#define SleepTimer_PRESCALER_SHIFT                (8u)
#define SleepTimer_UPDOWN_SHIFT                   (16u)
#define SleepTimer_ONESHOT_SHIFT                  (18u)
#define SleepTimer_QUAD_MODE_SHIFT                (20u)
#define SleepTimer_INV_OUT_SHIFT                  (20u)
#define SleepTimer_INV_COMPL_OUT_SHIFT            (21u)
#define SleepTimer_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define SleepTimer_RELOAD_CC_MASK                 ((uint32)(SleepTimer_1BIT_MASK        <<  \
                                                                            SleepTimer_RELOAD_CC_SHIFT))
#define SleepTimer_RELOAD_PERIOD_MASK             ((uint32)(SleepTimer_1BIT_MASK        <<  \
                                                                            SleepTimer_RELOAD_PERIOD_SHIFT))
#define SleepTimer_PWM_SYNC_KILL_MASK             ((uint32)(SleepTimer_1BIT_MASK        <<  \
                                                                            SleepTimer_PWM_SYNC_KILL_SHIFT))
#define SleepTimer_PWM_STOP_KILL_MASK             ((uint32)(SleepTimer_1BIT_MASK        <<  \
                                                                            SleepTimer_PWM_STOP_KILL_SHIFT))
#define SleepTimer_PRESCALER_MASK                 ((uint32)(SleepTimer_8BIT_MASK        <<  \
                                                                            SleepTimer_PRESCALER_SHIFT))
#define SleepTimer_UPDOWN_MASK                    ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                            SleepTimer_UPDOWN_SHIFT))
#define SleepTimer_ONESHOT_MASK                   ((uint32)(SleepTimer_1BIT_MASK        <<  \
                                                                            SleepTimer_ONESHOT_SHIFT))
#define SleepTimer_QUAD_MODE_MASK                 ((uint32)(SleepTimer_3BIT_MASK        <<  \
                                                                            SleepTimer_QUAD_MODE_SHIFT))
#define SleepTimer_INV_OUT_MASK                   ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                            SleepTimer_INV_OUT_SHIFT))
#define SleepTimer_MODE_MASK                      ((uint32)(SleepTimer_3BIT_MASK        <<  \
                                                                            SleepTimer_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define SleepTimer_CAPTURE_SHIFT                  (0u)
#define SleepTimer_COUNT_SHIFT                    (2u)
#define SleepTimer_RELOAD_SHIFT                   (4u)
#define SleepTimer_STOP_SHIFT                     (6u)
#define SleepTimer_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define SleepTimer_CAPTURE_MASK                   ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                  SleepTimer_CAPTURE_SHIFT))
#define SleepTimer_COUNT_MASK                     ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                  SleepTimer_COUNT_SHIFT))
#define SleepTimer_RELOAD_MASK                    ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                  SleepTimer_RELOAD_SHIFT))
#define SleepTimer_STOP_MASK                      ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                  SleepTimer_STOP_SHIFT))
#define SleepTimer_START_MASK                     ((uint32)(SleepTimer_2BIT_MASK        <<  \
                                                                  SleepTimer_START_SHIFT))

/* MASK */
#define SleepTimer_1BIT_MASK                      ((uint32)0x01u)
#define SleepTimer_2BIT_MASK                      ((uint32)0x03u)
#define SleepTimer_3BIT_MASK                      ((uint32)0x07u)
#define SleepTimer_6BIT_MASK                      ((uint32)0x3Fu)
#define SleepTimer_8BIT_MASK                      ((uint32)0xFFu)
#define SleepTimer_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define SleepTimer_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define SleepTimer_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(SleepTimer_QUAD_ENCODING_MODES     << SleepTimer_QUAD_MODE_SHIFT))       |\
         ((uint32)(SleepTimer_CONFIG                  << SleepTimer_MODE_SHIFT)))

#define SleepTimer_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(SleepTimer_PWM_STOP_EVENT          << SleepTimer_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(SleepTimer_PWM_OUT_INVERT          << SleepTimer_INV_OUT_SHIFT))         |\
         ((uint32)(SleepTimer_PWM_OUT_N_INVERT        << SleepTimer_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(SleepTimer_PWM_MODE                << SleepTimer_MODE_SHIFT)))

#define SleepTimer_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(SleepTimer_PWM_RUN_MODE         << SleepTimer_ONESHOT_SHIFT))
            
#define SleepTimer_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(SleepTimer_PWM_ALIGN            << SleepTimer_UPDOWN_SHIFT))

#define SleepTimer_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(SleepTimer_PWM_KILL_EVENT      << SleepTimer_PWM_SYNC_KILL_SHIFT))

#define SleepTimer_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(SleepTimer_PWM_DEAD_TIME_CYCLE  << SleepTimer_PRESCALER_SHIFT))

#define SleepTimer_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(SleepTimer_PWM_PRESCALER        << SleepTimer_PRESCALER_SHIFT))

#define SleepTimer_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(SleepTimer_TC_PRESCALER            << SleepTimer_PRESCALER_SHIFT))       |\
         ((uint32)(SleepTimer_TC_COUNTER_MODE         << SleepTimer_UPDOWN_SHIFT))          |\
         ((uint32)(SleepTimer_TC_RUN_MODE             << SleepTimer_ONESHOT_SHIFT))         |\
         ((uint32)(SleepTimer_TC_COMP_CAP_MODE        << SleepTimer_MODE_SHIFT)))
        
#define SleepTimer_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(SleepTimer_QUAD_PHIA_SIGNAL_MODE   << SleepTimer_COUNT_SHIFT))           |\
         ((uint32)(SleepTimer_QUAD_INDEX_SIGNAL_MODE  << SleepTimer_RELOAD_SHIFT))          |\
         ((uint32)(SleepTimer_QUAD_STOP_SIGNAL_MODE   << SleepTimer_STOP_SHIFT))            |\
         ((uint32)(SleepTimer_QUAD_PHIB_SIGNAL_MODE   << SleepTimer_START_SHIFT)))

#define SleepTimer_PWM_SIGNALS_MODES                                                              \
        (((uint32)(SleepTimer_PWM_SWITCH_SIGNAL_MODE  << SleepTimer_CAPTURE_SHIFT))         |\
         ((uint32)(SleepTimer_PWM_COUNT_SIGNAL_MODE   << SleepTimer_COUNT_SHIFT))           |\
         ((uint32)(SleepTimer_PWM_RELOAD_SIGNAL_MODE  << SleepTimer_RELOAD_SHIFT))          |\
         ((uint32)(SleepTimer_PWM_STOP_SIGNAL_MODE    << SleepTimer_STOP_SHIFT))            |\
         ((uint32)(SleepTimer_PWM_START_SIGNAL_MODE   << SleepTimer_START_SHIFT)))

#define SleepTimer_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(SleepTimer_TC_CAPTURE_SIGNAL_MODE  << SleepTimer_CAPTURE_SHIFT))         |\
         ((uint32)(SleepTimer_TC_COUNT_SIGNAL_MODE    << SleepTimer_COUNT_SHIFT))           |\
         ((uint32)(SleepTimer_TC_RELOAD_SIGNAL_MODE   << SleepTimer_RELOAD_SHIFT))          |\
         ((uint32)(SleepTimer_TC_STOP_SIGNAL_MODE     << SleepTimer_STOP_SHIFT))            |\
         ((uint32)(SleepTimer_TC_START_SIGNAL_MODE    << SleepTimer_START_SHIFT)))
        
#define SleepTimer_TIMER_UPDOWN_CNT_USED                                                          \
                ((SleepTimer__COUNT_UPDOWN0 == SleepTimer_TC_COUNTER_MODE)                  ||\
                 (SleepTimer__COUNT_UPDOWN1 == SleepTimer_TC_COUNTER_MODE))

#define SleepTimer_PWM_UPDOWN_CNT_USED                                                            \
                ((SleepTimer__CENTER == SleepTimer_PWM_ALIGN)                               ||\
                 (SleepTimer__ASYMMETRIC == SleepTimer_PWM_ALIGN))               
        
#define SleepTimer_PWM_PR_INIT_VALUE              (1u)
#define SleepTimer_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_SleepTimer_H */

/* [] END OF FILE */
