/*******************************************************************************
* File Name: SleepTimer.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the SleepTimer
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SleepTimer.h"

uint8 SleepTimer_initVar = 0u;


/*******************************************************************************
* Function Name: SleepTimer_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default SleepTimer configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (SleepTimer__QUAD == SleepTimer_CONFIG)
        SleepTimer_CONTROL_REG = SleepTimer_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        SleepTimer_TRIG_CONTROL1_REG  = SleepTimer_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        SleepTimer_SetInterruptMode(SleepTimer_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        SleepTimer_SetCounterMode(SleepTimer_COUNT_DOWN);
        SleepTimer_WritePeriod(SleepTimer_QUAD_PERIOD_INIT_VALUE);
        SleepTimer_WriteCounter(SleepTimer_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (SleepTimer__QUAD == SleepTimer_CONFIG) */

    #if (SleepTimer__TIMER == SleepTimer_CONFIG)
        SleepTimer_CONTROL_REG = SleepTimer_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        SleepTimer_TRIG_CONTROL1_REG  = SleepTimer_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        SleepTimer_SetInterruptMode(SleepTimer_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        SleepTimer_WritePeriod(SleepTimer_TC_PERIOD_VALUE );

        #if (SleepTimer__COMPARE == SleepTimer_TC_COMP_CAP_MODE)
            SleepTimer_WriteCompare(SleepTimer_TC_COMPARE_VALUE);

            #if (1u == SleepTimer_TC_COMPARE_SWAP)
                SleepTimer_SetCompareSwap(1u);
                SleepTimer_WriteCompareBuf(SleepTimer_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == SleepTimer_TC_COMPARE_SWAP) */
        #endif  /* (SleepTimer__COMPARE == SleepTimer_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (SleepTimer_CY_TCPWM_V2 && SleepTimer_TIMER_UPDOWN_CNT_USED && !SleepTimer_CY_TCPWM_4000)
            SleepTimer_WriteCounter(1u);
        #elif(SleepTimer__COUNT_DOWN == SleepTimer_TC_COUNTER_MODE)
            SleepTimer_WriteCounter(SleepTimer_TC_PERIOD_VALUE);
        #else
            SleepTimer_WriteCounter(0u);
        #endif /* (SleepTimer_CY_TCPWM_V2 && SleepTimer_TIMER_UPDOWN_CNT_USED && !SleepTimer_CY_TCPWM_4000) */
    #endif  /* (SleepTimer__TIMER == SleepTimer_CONFIG) */

    #if (SleepTimer__PWM_SEL == SleepTimer_CONFIG)
        SleepTimer_CONTROL_REG = SleepTimer_CTRL_PWM_BASE_CONFIG;

        #if (SleepTimer__PWM_PR == SleepTimer_PWM_MODE)
            SleepTimer_CONTROL_REG |= SleepTimer_CTRL_PWM_RUN_MODE;
            SleepTimer_WriteCounter(SleepTimer_PWM_PR_INIT_VALUE);
        #else
            SleepTimer_CONTROL_REG |= SleepTimer_CTRL_PWM_ALIGN | SleepTimer_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (SleepTimer_CY_TCPWM_V2 && SleepTimer_PWM_UPDOWN_CNT_USED && !SleepTimer_CY_TCPWM_4000)
                SleepTimer_WriteCounter(1u);
            #elif (SleepTimer__RIGHT == SleepTimer_PWM_ALIGN)
                SleepTimer_WriteCounter(SleepTimer_PWM_PERIOD_VALUE);
            #else 
                SleepTimer_WriteCounter(0u);
            #endif  /* (SleepTimer_CY_TCPWM_V2 && SleepTimer_PWM_UPDOWN_CNT_USED && !SleepTimer_CY_TCPWM_4000) */
        #endif  /* (SleepTimer__PWM_PR == SleepTimer_PWM_MODE) */

        #if (SleepTimer__PWM_DT == SleepTimer_PWM_MODE)
            SleepTimer_CONTROL_REG |= SleepTimer_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (SleepTimer__PWM_DT == SleepTimer_PWM_MODE) */

        #if (SleepTimer__PWM == SleepTimer_PWM_MODE)
            SleepTimer_CONTROL_REG |= SleepTimer_CTRL_PWM_PRESCALER;
        #endif  /* (SleepTimer__PWM == SleepTimer_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        SleepTimer_TRIG_CONTROL1_REG  = SleepTimer_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        SleepTimer_SetInterruptMode(SleepTimer_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (SleepTimer__PWM_PR == SleepTimer_PWM_MODE)
            SleepTimer_TRIG_CONTROL2_REG =
                    (SleepTimer_CC_MATCH_NO_CHANGE    |
                    SleepTimer_OVERLOW_NO_CHANGE      |
                    SleepTimer_UNDERFLOW_NO_CHANGE);
        #else
            #if (SleepTimer__LEFT == SleepTimer_PWM_ALIGN)
                SleepTimer_TRIG_CONTROL2_REG = SleepTimer_PWM_MODE_LEFT;
            #endif  /* ( SleepTimer_PWM_LEFT == SleepTimer_PWM_ALIGN) */

            #if (SleepTimer__RIGHT == SleepTimer_PWM_ALIGN)
                SleepTimer_TRIG_CONTROL2_REG = SleepTimer_PWM_MODE_RIGHT;
            #endif  /* ( SleepTimer_PWM_RIGHT == SleepTimer_PWM_ALIGN) */

            #if (SleepTimer__CENTER == SleepTimer_PWM_ALIGN)
                SleepTimer_TRIG_CONTROL2_REG = SleepTimer_PWM_MODE_CENTER;
            #endif  /* ( SleepTimer_PWM_CENTER == SleepTimer_PWM_ALIGN) */

            #if (SleepTimer__ASYMMETRIC == SleepTimer_PWM_ALIGN)
                SleepTimer_TRIG_CONTROL2_REG = SleepTimer_PWM_MODE_ASYM;
            #endif  /* (SleepTimer__ASYMMETRIC == SleepTimer_PWM_ALIGN) */
        #endif  /* (SleepTimer__PWM_PR == SleepTimer_PWM_MODE) */

        /* Set other values from customizer */
        SleepTimer_WritePeriod(SleepTimer_PWM_PERIOD_VALUE );
        SleepTimer_WriteCompare(SleepTimer_PWM_COMPARE_VALUE);

        #if (1u == SleepTimer_PWM_COMPARE_SWAP)
            SleepTimer_SetCompareSwap(1u);
            SleepTimer_WriteCompareBuf(SleepTimer_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == SleepTimer_PWM_COMPARE_SWAP) */

        #if (1u == SleepTimer_PWM_PERIOD_SWAP)
            SleepTimer_SetPeriodSwap(1u);
            SleepTimer_WritePeriodBuf(SleepTimer_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == SleepTimer_PWM_PERIOD_SWAP) */
    #endif  /* (SleepTimer__PWM_SEL == SleepTimer_CONFIG) */
    
}


/*******************************************************************************
* Function Name: SleepTimer_Enable
********************************************************************************
*
* Summary:
*  Enables the SleepTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    SleepTimer_BLOCK_CONTROL_REG |= SleepTimer_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (SleepTimer__PWM_SEL == SleepTimer_CONFIG)
        #if (0u == SleepTimer_PWM_START_SIGNAL_PRESENT)
            SleepTimer_TriggerCommand(SleepTimer_MASK, SleepTimer_CMD_START);
        #endif /* (0u == SleepTimer_PWM_START_SIGNAL_PRESENT) */
    #endif /* (SleepTimer__PWM_SEL == SleepTimer_CONFIG) */

    #if (SleepTimer__TIMER == SleepTimer_CONFIG)
        #if (0u == SleepTimer_TC_START_SIGNAL_PRESENT)
            SleepTimer_TriggerCommand(SleepTimer_MASK, SleepTimer_CMD_START);
        #endif /* (0u == SleepTimer_TC_START_SIGNAL_PRESENT) */
    #endif /* (SleepTimer__TIMER == SleepTimer_CONFIG) */
}


/*******************************************************************************
* Function Name: SleepTimer_Start
********************************************************************************
*
* Summary:
*  Initializes the SleepTimer with default customizer
*  values when called the first time and enables the SleepTimer.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  SleepTimer_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time SleepTimer_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the SleepTimer_Start() routine.
*
*******************************************************************************/
void SleepTimer_Start(void)
{
    if (0u == SleepTimer_initVar)
    {
        SleepTimer_Init();
        SleepTimer_initVar = 1u;
    }

    SleepTimer_Enable();
}


/*******************************************************************************
* Function Name: SleepTimer_Stop
********************************************************************************
*
* Summary:
*  Disables the SleepTimer.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_BLOCK_CONTROL_REG &= (uint32)~SleepTimer_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the SleepTimer. This function is used when
*  configured as a generic SleepTimer and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the SleepTimer to operate in
*   Values:
*   - SleepTimer_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - SleepTimer_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - SleepTimer_MODE_QUAD - Quadrature decoder
*         - SleepTimer_MODE_PWM - PWM
*         - SleepTimer_MODE_PWM_DT - PWM with dead time
*         - SleepTimer_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_MODE_MASK;
    SleepTimer_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - SleepTimer_MODE_X1 - Counts on phi 1 rising
*         - SleepTimer_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - SleepTimer_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_QUAD_MODE_MASK;
    SleepTimer_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - SleepTimer_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - SleepTimer_PRESCALE_DIVBY2    - Divide by 2
*         - SleepTimer_PRESCALE_DIVBY4    - Divide by 4
*         - SleepTimer_PRESCALE_DIVBY8    - Divide by 8
*         - SleepTimer_PRESCALE_DIVBY16   - Divide by 16
*         - SleepTimer_PRESCALE_DIVBY32   - Divide by 32
*         - SleepTimer_PRESCALE_DIVBY64   - Divide by 64
*         - SleepTimer_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_PRESCALER_MASK;
    SleepTimer_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the SleepTimer runs
*  continuously or stops when terminal count is reached.  By default the
*  SleepTimer operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_ONESHOT_MASK;
    SleepTimer_CONTROL_REG |= ((uint32)((oneShotEnable & SleepTimer_1BIT_MASK) <<
                                                               SleepTimer_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPWMMode(uint32 modeMask)
{
    SleepTimer_TRIG_CONTROL2_REG = (modeMask & SleepTimer_6BIT_MASK);
}



/*******************************************************************************
* Function Name: SleepTimer_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_PWM_SYNC_KILL_MASK;
    SleepTimer_CONTROL_REG |= ((uint32)((syncKillEnable & SleepTimer_1BIT_MASK)  <<
                                               SleepTimer_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_PWM_STOP_KILL_MASK;
    SleepTimer_CONTROL_REG |= ((uint32)((stopOnKillEnable & SleepTimer_1BIT_MASK)  <<
                                                         SleepTimer_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_PRESCALER_MASK;
    SleepTimer_CONTROL_REG |= ((uint32)((deadTime & SleepTimer_8BIT_MASK) <<
                                                          SleepTimer_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - SleepTimer_INVERT_LINE   - Inverts the line output
*         - SleepTimer_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_INV_OUT_MASK;
    SleepTimer_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: SleepTimer_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_WriteCounter(uint32 count)
{
    SleepTimer_COUNTER_REG = (count & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 SleepTimer_ReadCounter(void)
{
    return (SleepTimer_COUNTER_REG & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - SleepTimer_COUNT_UP       - Counts up
*     - SleepTimer_COUNT_DOWN     - Counts down
*     - SleepTimer_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - SleepTimer_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_UPDOWN_MASK;
    SleepTimer_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_WritePeriod(uint32 period)
{
    SleepTimer_PERIOD_REG = (period & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 SleepTimer_ReadPeriod(void)
{
    return (SleepTimer_PERIOD_REG & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_RELOAD_CC_MASK;
    SleepTimer_CONTROL_REG |= (swapEnable & SleepTimer_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_WritePeriodBuf(uint32 periodBuf)
{
    SleepTimer_PERIOD_BUF_REG = (periodBuf & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 SleepTimer_ReadPeriodBuf(void)
{
    return (SleepTimer_PERIOD_BUF_REG & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_CONTROL_REG &= (uint32)~SleepTimer_RELOAD_PERIOD_MASK;
    SleepTimer_CONTROL_REG |= ((uint32)((swapEnable & SleepTimer_1BIT_MASK) <<
                                                            SleepTimer_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_WriteCompare(uint32 compare)
{
    #if (SleepTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (SleepTimer_CY_TCPWM_4000) */

    #if (SleepTimer_CY_TCPWM_4000)
        currentMode = ((SleepTimer_CONTROL_REG & SleepTimer_UPDOWN_MASK) >> SleepTimer_UPDOWN_SHIFT);

        if (((uint32)SleepTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)SleepTimer__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (SleepTimer_CY_TCPWM_4000) */
    
    SleepTimer_COMP_CAP_REG = (compare & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 SleepTimer_ReadCompare(void)
{
    #if (SleepTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (SleepTimer_CY_TCPWM_4000) */

    #if (SleepTimer_CY_TCPWM_4000)
        currentMode = ((SleepTimer_CONTROL_REG & SleepTimer_UPDOWN_MASK) >> SleepTimer_UPDOWN_SHIFT);
        
        regVal = SleepTimer_COMP_CAP_REG;
        
        if (((uint32)SleepTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)SleepTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & SleepTimer_16BIT_MASK);
    #else
        return (SleepTimer_COMP_CAP_REG & SleepTimer_16BIT_MASK);
    #endif /* (SleepTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: SleepTimer_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_WriteCompareBuf(uint32 compareBuf)
{
    #if (SleepTimer_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (SleepTimer_CY_TCPWM_4000) */

    #if (SleepTimer_CY_TCPWM_4000)
        currentMode = ((SleepTimer_CONTROL_REG & SleepTimer_UPDOWN_MASK) >> SleepTimer_UPDOWN_SHIFT);

        if (((uint32)SleepTimer__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)SleepTimer__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (SleepTimer_CY_TCPWM_4000) */
    
    SleepTimer_COMP_CAP_BUF_REG = (compareBuf & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 SleepTimer_ReadCompareBuf(void)
{
    #if (SleepTimer_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (SleepTimer_CY_TCPWM_4000) */

    #if (SleepTimer_CY_TCPWM_4000)
        currentMode = ((SleepTimer_CONTROL_REG & SleepTimer_UPDOWN_MASK) >> SleepTimer_UPDOWN_SHIFT);

        regVal = SleepTimer_COMP_CAP_BUF_REG;
        
        if (((uint32)SleepTimer__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)SleepTimer__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & SleepTimer_16BIT_MASK);
    #else
        return (SleepTimer_COMP_CAP_BUF_REG & SleepTimer_16BIT_MASK);
    #endif /* (SleepTimer_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: SleepTimer_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 SleepTimer_ReadCapture(void)
{
    return (SleepTimer_COMP_CAP_REG & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 SleepTimer_ReadCaptureBuf(void)
{
    return (SleepTimer_COMP_CAP_BUF_REG & SleepTimer_16BIT_MASK);
}


/*******************************************************************************
* Function Name: SleepTimer_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SleepTimer_TRIG_LEVEL     - Level
*     - SleepTimer_TRIG_RISING    - Rising edge
*     - SleepTimer_TRIG_FALLING   - Falling edge
*     - SleepTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_TRIG_CONTROL1_REG &= (uint32)~SleepTimer_CAPTURE_MASK;
    SleepTimer_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SleepTimer_TRIG_LEVEL     - Level
*     - SleepTimer_TRIG_RISING    - Rising edge
*     - SleepTimer_TRIG_FALLING   - Falling edge
*     - SleepTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_TRIG_CONTROL1_REG &= (uint32)~SleepTimer_RELOAD_MASK;
    SleepTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SleepTimer_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SleepTimer_TRIG_LEVEL     - Level
*     - SleepTimer_TRIG_RISING    - Rising edge
*     - SleepTimer_TRIG_FALLING   - Falling edge
*     - SleepTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_TRIG_CONTROL1_REG &= (uint32)~SleepTimer_START_MASK;
    SleepTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SleepTimer_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SleepTimer_TRIG_LEVEL     - Level
*     - SleepTimer_TRIG_RISING    - Rising edge
*     - SleepTimer_TRIG_FALLING   - Falling edge
*     - SleepTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_TRIG_CONTROL1_REG &= (uint32)~SleepTimer_STOP_MASK;
    SleepTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SleepTimer_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - SleepTimer_TRIG_LEVEL     - Level
*     - SleepTimer_TRIG_RISING    - Rising edge
*     - SleepTimer_TRIG_FALLING   - Falling edge
*     - SleepTimer_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_TRIG_CONTROL1_REG &= (uint32)~SleepTimer_COUNT_MASK;
    SleepTimer_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << SleepTimer_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - SleepTimer_CMD_CAPTURE    - Trigger Capture command
*     - SleepTimer_CMD_RELOAD     - Trigger Reload command
*     - SleepTimer_CMD_STOP       - Trigger Stop command
*     - SleepTimer_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    SleepTimer_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: SleepTimer_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the SleepTimer.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - SleepTimer_STATUS_DOWN    - Set if counting down
*     - SleepTimer_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 SleepTimer_ReadStatus(void)
{
    return ((SleepTimer_STATUS_REG >> SleepTimer_RUNNING_STATUS_SHIFT) |
            (SleepTimer_STATUS_REG & SleepTimer_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: SleepTimer_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - SleepTimer_INTR_MASK_TC       - Terminal count mask
*     - SleepTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetInterruptMode(uint32 interruptMask)
{
    SleepTimer_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: SleepTimer_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - SleepTimer_INTR_MASK_TC       - Terminal count mask
*     - SleepTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 SleepTimer_GetInterruptSourceMasked(void)
{
    return (SleepTimer_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: SleepTimer_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - SleepTimer_INTR_MASK_TC       - Terminal count mask
*     - SleepTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 SleepTimer_GetInterruptSource(void)
{
    return (SleepTimer_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: SleepTimer_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - SleepTimer_INTR_MASK_TC       - Terminal count mask
*     - SleepTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_ClearInterrupt(uint32 interruptMask)
{
    SleepTimer_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: SleepTimer_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - SleepTimer_INTR_MASK_TC       - Terminal count mask
*     - SleepTimer_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SetInterrupt(uint32 interruptMask)
{
    SleepTimer_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
