/*******************************************************************************
* File Name: SleepTimer_PM.c
* Version 2.0
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SleepTimer.h"

static SleepTimer_BACKUP_STRUCT SleepTimer_backup;


/*******************************************************************************
* Function Name: SleepTimer_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: SleepTimer_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_Sleep(void)
{
    if(0u != (SleepTimer_BLOCK_CONTROL_REG & SleepTimer_MASK))
    {
        SleepTimer_backup.enableState = 1u;
    }
    else
    {
        SleepTimer_backup.enableState = 0u;
    }

    SleepTimer_Stop();
    SleepTimer_SaveConfig();
}


/*******************************************************************************
* Function Name: SleepTimer_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: SleepTimer_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SleepTimer_Wakeup(void)
{
    SleepTimer_RestoreConfig();

    if(0u != SleepTimer_backup.enableState)
    {
        SleepTimer_Enable();
    }
}


/* [] END OF FILE */
